@@ -395,17 +395,20 @@ def save_sw_data(company_info_type):
 def get_recent_year_income(symbol, company_info_type, exist_company_df):
     now_date = datetime.now()
     hour = now_date.hour
-    if hour <= 15:
-        exist_company_one_df = exist_company_df.loc[exist_company_df['_id'] == symbol]
-        if data_frame_util.is_not_empty(exist_company_one_df):
-            company_info_type['operate_profit'] = list(exist_company_one_df['operate_profit'])[0]
-            company_info_type['total_operate_income'] = list(exist_company_one_df['total_operate_income'])[0]
-            company_info_type['operate_date_name'] = ''
-        else:
-            company_info_type['operate_profit'] = 0
-            company_info_type['total_operate_income'] = 0
-            company_info_type['operate_date_name'] = ''
-        return company_info_type
+    # if hour <= 15:
+    #     exist_company_one_df = exist_company_df.loc[exist_company_df['_id'] == symbol]
+    #     if data_frame_util.is_not_empty(exist_company_one_df):
+    #         company_info_type['operate_profit'] = list(exist_company_one_df['operate_profit'])[0]
+    #         company_info_type['total_operate_income'] = list(exist_company_one_df['total_operate_income'])[0]
+    #         if 'operate_date_name' in exist_company_one_df:
+    #             company_info_type['operate_date_name'] = list(exist_company_one_df['total_operate_income'])[0]
+    #         else:
+    #             company_info_type['operate_date_name'] = '暂无年报'
+    #     else:
+    #         company_info_type['operate_profit'] = 0
+    #         company_info_type['total_operate_income'] = 0
+    #         company_info_type['operate_date_name'] = '暂无年报'
+    #     return company_info_type
     query = {'symbol': symbol, "REPORT_TYPE": "年报"}
     em_stock_profit = mongodb_util.descend_query(query, db_name_constant.EM_STOCK_PROFIT, 'REPORT_DATE', 1)
     if data_frame_util.is_not_empty(em_stock_profit):
@@ -420,7 +423,7 @@ def get_recent_year_income(symbol, company_info_type, exist_company_df):
     else:
         company_info_type['operate_profit'] = 0
         company_info_type['total_operate_income'] = 0
-        company_info_type['operate_date_name'] = ''
+        company_info_type['operate_date_name'] = '暂无年报'
     company_info_type['operate_profit'] = round(
         company_info_type['operate_profit'] / common_service_fun_api.HUNDRED_MILLION, 2)
     company_info_type['total_operate_income'] = round(
