@@ -14,8 +14,18 @@ remote_mongodb_util = RemoteMongodbUtil('27017')
 local_mongodb_util = LocalMongodbUtil('27017')
 
 
+def create_index(db_name):
+    local_mongodb_util.create_index(db_name, [("symbol", 1)])
+
+    local_mongodb_util.create_index(db_name, [("str_now_date", 1)])
+
+    local_mongodb_util.create_index(db_name, [("symbol", 1), ("number", 1)])
+
+
 def sync_real_time_data(str_day, min_number, max_number):
     db_name = 'realtime_quotes_now_' + str_day
+    # 创建索引
+    create_index(db_name)
     while min_number <= max_number:
         query = {'number': min_number}
         data_df = remote_mongodb_util.find_query_data(db_name, query)
@@ -29,17 +39,18 @@ def sync_k_line(str_day):
     db_name = 'k_line_info'
     data_df = remote_mongodb_util.find_query_data(db_name, query)
     try:
-        local_mongodb_util.save_mongo(data_df, db_name)
+        local_mongodb_util.insert_mongo(data_df, db_name)
     except BaseException as e:
         logger.error("出现异常:{}", e)
         pass
 
 
 if __name__ == '__main__':
-
-    str_day_01 = '2025-02-27'
-    sync_real_time_data(str_day_01, 1, 2000)
+    str_day_01 = '2025-09-10'
     sync_k_line(str_day_01)
+
+    # sync_real_time_data(str_day_01, 1, 2500)
+
     # sync_k_line(str_day_01)
     # sync_k_line('2024-11-13')
     # sync_k_line('2024-11-12')
