@@ -53,13 +53,14 @@ import mns_scheduler.company_info.clean.company_info_clean_api as company_info_c
 import mns_scheduler.zt.zt_pool.ths_zt_pool_sync_api as ths_zt_pool_sync_api
 import mns_scheduler.trade.task.trader_task_service as trader_task_service
 import mns_scheduler.company_info.remark.company_remark_info_sync as company_remark_info_sync
-import mns_scheduler.finance.sync_financial_report_service_api as sync_financial_report_service_api
+import mns_scheduler.finance.sync_financial_report_service_task as sync_financial_report_service_task
 import mns_scheduler.hk.hk_industry_info_sync_service_api as hk_industry_info_sync_service_api
 import mns_scheduler.hk.hk_company_info_sync_service_api as hk_company_info_sync_service_api
 import mns_scheduler.zt.zt_pool.update_null_zt_reason_api as update_null_zt_reason_api
 import mns_scheduler.trade.tfp.stock_tfp_info_sync as stock_tfp_info_sync
 import mns_scheduler.industry.ths.ths_industry_sync_service as ths_industry_sync_service
 import mns_scheduler.k_line.year_quarter.year_quarter_line_sync as year_quarter_line_sync
+import mns_scheduler.k_line.sync_status.k_line_sync_status_check as k_line_sync_status_check
 
 
 # 同步交易日期任务完成
@@ -387,7 +388,7 @@ def self_choose_stock_task():
 # 同步财务报表
 def sync_financial_report_task():
     logger.info('同步财务报表任务')
-    sync_financial_report_service_api.sync_financial_report()
+    sync_financial_report_service_task.sync_financial_report()
 
 
 # 同步hk公司信息
@@ -438,6 +439,12 @@ def sync_all_em_stock_info():
     sync_em_stock_info_sync.sync_all_em_stock_info()
 
 
+# check 前复权k线和下一个交易日策略k线数据同步状态
+def check_k_line_sync_count():
+    logger.info("check前复权k线和下一个交易日策略k线数据同步状态")
+    k_line_sync_status_check.check_k_line_sync_count()
+
+
 # # 定义BlockingScheduler
 blockingScheduler = BlockingScheduler()
 
@@ -552,6 +559,9 @@ blockingScheduler.add_job(sync_all_kpl_plate_info, 'interval', minutes=5, max_in
 # 同步新公告信息 感觉没有必要同步 直接连接过去查看
 # blockingScheduler.add_job(sync_company_announce, 'cron', hour='07,18,23', minute='33')
 
+#  check 前复权k线和下一个交易日策略k线数据同步状态
+blockingScheduler.add_job(check_k_line_sync_count, 'cron', hour='0,23', minute='10')
+
 print('定时任务启动成功')
 blockingScheduler.start()
 #
